<!doctype html>
{% load staticfiles %}
{% load compress %}

<html class="no-js" lang="">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <title></title>
        <meta name="description" content="">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        {% compress css %}
        <link rel="stylesheet" href="{% static 'css/bootstrap.min.css' %}"/>
        <link rel="stylesheet" href="{% static 'css/bootstrap-theme.min.css' %}"/>
        {% endcompress %}
    </head>
    <body>
        <!--[if lt IE 8]>
            <p class="browserupgrade">You are using an <strong>outdated</strong> browser. Please <a href="http://browsehappy.com/">upgrade your browser</a> to improve your experience.</p>
        <![endif]-->
        {% block body %}
            <div class="well">
                <h2>It Works</h2>
            </div>
        {% endblock %}

        {% block scripts %}
            {% compress js %}
                {% include '_marionettejs.html' %}
            {% endcompress %}
        {% endblock %}
    </body>
</html>
