{% extends 'marionettejs.html' %}
{% load staticfiles %}

{% block extra %}

<script src="{% static 'js/handlebars-v3.0.0.js' %}"></script>
<script>
    Backbone.Marionette.TemplateCache.prototype.compileTemplate = function(rawTemplate) {
        // use Handlebars.js to compile the template
        return Handlebars.compile(rawTemplate);
    }
</script>

{% endblock %}
